/***************************************************************************//**
 *   @file   YRDKRX63N.h
 *   @brief  Header file of YRDKRX63N Driver.
 *   @author Bancisor Mihai
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 777
*******************************************************************************/

/******************************************************************************/
/* Include Files                                                              */
/******************************************************************************/
#include "YRDKRX63N.h"

/***************************************************************************//**
 * @brief Reset the YRDKRX63N's peripherals.
 *
 * @param None.
 *
 * @return None.
*******************************************************************************/
void YRDKRX63N_Reset(void)
{
    unsigned short delay;
	ST7579_RESET_PIN_OUT;
	ST7579_RESET_HIGH;
    for(delay = 0;delay < 1000;delay ++)
    {
		nop();
    }
	ST7579_RESET_LOW;
}

/***************************************************************************//**
 * @brief Initializes the YRDKRX63N.
 *
 * @param None.
 *
 * @return None.
*******************************************************************************/
void YRDKRX63N_Init(void)
{
	YRDKRX63N_Reset();
	/* Set the LOCO clock settings (the clock source used after a power-on reset) */
	/* ICLK = 125 kHz, PCLKA = 125 kHz, PCLKB = 125 kHz, FCLK = 125 kHz */
	/* BCLK = IECLK = UCLK = not used */
	R_CGC_Set(
			PDL_CGC_CLK_LOCO,
			PDL_CGC_BCLK_DISABLE | PDL_CGC_SDCLK_DISABLE,
			125E3,
			125E3,
			125E3,
			125E3,
			125E3,
			PDL_NO_DATA,
			PDL_NO_DATA,
			PDL_NO_DATA
			);
	/* Configure main clock operation using a 12.0 MHz crystal */
	/* ICLK = 3 MHz, PCLKA = 3 MHz, PCLKB = 3 MHz, FCLK = 3 MHz */
	/* BCLK = IECLK = UCLK = not used */
	R_CGC_Set(
			PDL_CGC_CLK_MAIN,
			PDL_CGC_BCLK_DISABLE | PDL_CGC_SDCLK_DISABLE,
			12E6,
			3E6,
			3E6,
			3E6,
			3E6,
			PDL_NO_DATA,
			PDL_NO_DATA,
			PDL_NO_DATA
			);
	/* Configure PLL operation. The PLL will be set to 192 MHz */
	/* ICLK = 96 MHz, PCLKA = 96 MHz, PCLKB = 48 MHz, FCLK = 48 MHz */
	/* BCLK = 48 MHz, BCLK(pin) = 24 MHz. */
	/* IECLK = UCLK = not used */
	R_CGC_Set(
			PDL_CGC_CLK_PLL,
			PDL_CGC_BCLK_DIV_2 | PDL_CGC_SDCLK_DISABLE,
			192E6,
			96E6,
			48E6,
			48E6,
			48E6,
			48E6,
			PDL_NO_DATA,
			PDL_NO_DATA
			);

	/* Allow time for the main clock and PLL oscillator to stabilise. This example */
	/* uses the CMT timer (running from the LOCO) to generate a 100 s delay */
	/* Generate the 100 s delay */
	R_CMT_CreateOneShot(
						0,
						PDL_NO_DATA,
						100E-6,
						PDL_NO_FUNC,
						0
						);
	/* Select the PLL as the clock source */
	R_CGC_Control(
				PDL_CGC_CLK_PLL,
				PDL_NO_DATA,
				PDL_NO_DATA
				);

	/* All LEDs connected to Port D off. */
	R_IO_PORT_Write(PDL_IO_PORT_D, 0xFF);
	/* Port D - Output. */
    R_IO_PORT_Set(LED14_PIN | LED10_PIN | LED6_PIN  | LED12_PIN |
				  LED8_PIN  | LED4_PIN  | LED15_PIN | LED11_PIN,
				  PDL_IO_PORT_OUTPUT | PDL_IO_PORT_TYPE_CMOS);
	/* All LEDs connected to Port E off. */
	R_IO_PORT_Write(PDL_IO_PORT_E, 0x0F);
	/* Port E - Pins 0, 1, 2, 3 output. */
    R_IO_PORT_Set(LED7_PIN | LED13_PIN | LED9_PIN | LED5_PIN,
				  PDL_IO_PORT_OUTPUT);
	/*< Configure a port pin for output */
	R_IO_PORT_Set(PDL_IO_PORT_E_0, PDL_IO_PORT_OUTPUT);
	R_IO_PORT_Set(PDL_IO_PORT_E_1, PDL_IO_PORT_OUTPUT);
	R_IO_PORT_Write(PDL_IO_PORT_E_0, 1); /* off LED1 */
	R_IO_PORT_Write(PDL_IO_PORT_E_1, 1); /* oFF LED2 */

					  
}
